@@ -1,55 +1,53 @@
 class EventHook(object):
-	"""
-	Simple event class used to provide hooks for different types of events in Locust.
-	
-	Here's how to use the EventHook class::
-	
-	    my_event = EventHook()
-	    def on_my_event(a, b):
-	        print "Event was fired with arguments: %s, %s" % (a, b)
-	    my_event += on_my_event
-	    my_event.fire("foo", "bar")
-	"""
-	
-	def __init__(self):
-		self._handlers = []
-	
-	def __iadd__(self, handler):
-		self._handlers.append(handler)
-		return self
-	
-	def __idec__(self, handler):
-		self._handlers.remove(handler)
-		return self
-	
-	def fire(self, *args, **kwargs):
-		for handler in self._handlers:
-			handler(*args, **kwargs)
+    """
+    Simple event class used to provide hooks for different types of events in Locust.
+
+    Here's how to use the EventHook class::
+
+        my_event = EventHook()
+        def on_my_event(a, b, **kw):
+            print "Event was fired with arguments: %s, %s" % (a, b)
+        my_event += on_my_event
+        my_event.fire(a="foo", b="bar")
+    """
+
+    def __init__(self):
+        self._handlers = []
+
+    def __iadd__(self, handler):
+        self._handlers.append(handler)
+        return self
+
+    def __isub__(self, handler):
+        self._handlers.remove(handler)
+        return self
+
+    def fire(self, **kwargs):
+        for handler in self._handlers:
+            handler(**kwargs)
 
 request_success = EventHook()
 """
-*request_success* is fired when an HTTP request is completed successfully.
+*request_success* is fired when a request is completed successfully.
 
 Listeners should take the following arguments:
 
-* *method*: HTTP Request method used
-* *path*: Path to the URL that was called (or override name if it was used in the call to the client)
+* *request_type*: Request type method used
+* *name*: Path to the URL that was called (or override name if it was used in the call to the client)
 * *response_time*: Response time in milliseconds
 * *response_length*: Content-length of the response
 """
 
 request_failure = EventHook()
 """
-*request_failure* is fired when an HTTP request fails
+*request_failure* is fired when a request fails
 
 Event is fired with the following arguments:
 
-* *method*: HTTP Request method used
-* *path*: Path to the URL that was called (or override name if it was used in the call to the client)
+* *request_type*: Request type method used
+* *name*: Path to the URL that was called (or override name if it was used in the call to the client)
 * *response_time*: Time in milliseconds until exception was thrown
 * *exception*: Exception instance that was thrown
-* *response*: If the failure was due to an HTTP error code (exception is an instance of urllib2.HTTPError),
-  then response will be an instance of locus.clients.HttpResponse. Otherwise response will be None.
 """
 
 locust_error = EventHook()
@@ -60,7 +58,7 @@ Event is fired with the following arguments:
 
 * *locust_instance*: Locust class instance where the exception occurred
 * *exception*: Exception that was thrown
-* *traceback*: Traceback object (from sys.exc_info()[2])
+* *tb*: Traceback object (from sys.exc_info()[2])
 """
 
 report_to_master = EventHook()
