@@ -1,13 +1,13 @@
-import random
+import base64
 import gevent
 import gevent.pywsgi
+import random
 import unittest
-import base64
 from copy import copy
 from StringIO import StringIO
 
 from locust import events
-from locust.stats import RequestStats
+from locust.stats import global_stats
 from flask import Flask, request, redirect, make_response, send_file
 
 app = Flask(__name__)
@@ -49,7 +49,7 @@ def failed_request():
     return "This response failed", 500
 
 @app.route("/redirect")
-def redirect():
+def do_redirect():
     return redirect("/ultra_fast")
 
 @app.route("/basic_auth")
@@ -63,7 +63,7 @@ def basic_auth():
 
 @app.route("/no_content_length")
 def no_content_length():
-    r = send_file(StringIO("This response does not have content-length in the header"))
+    r = send_file(StringIO("This response does not have content-length in the header"), add_etags=False)
     return r
 
 @app.errorhandler(404)
@@ -86,6 +86,27 @@ class LocustTestCase(unittest.TestCase):
     def tearDown(self):
         for event, handlers in self._event_handlers.iteritems():
             event._handlers = handlers
+    
+    def assertIn(self, member, container, msg=None):
+        """
+        Just like self.assertTrue(a in b), but with a nicer default message.
+        Implemented here to work with Python 2.6
+        """
+        
+        _MAX_LENGTH = 80
+        def safe_repr(obj, short=False):
+            try:
+                result = repr(obj)
+            except Exception:
+                result = object.__repr__(obj)
+            if not short or len(result) < _MAX_LENGTH:
+                return result
+            return result[:_MAX_LENGTH] + ' [truncated]...'
+        
+        if member not in container:
+            standardMsg = '%s not found in %s' % (safe_repr(member),
+                                                  safe_repr(container))
+            self.fail(self._formatMessage(msg, standardMsg))
 
             
 class WebserverTestCase(LocustTestCase):
@@ -98,8 +119,9 @@ class WebserverTestCase(LocustTestCase):
         gevent.spawn(lambda: self._web_server.serve_forever())
         gevent.sleep(0.01)
         self.port = self._web_server.server_port
-        RequestStats.requests = {}
+        global_stats.clear_all()
 
     def tearDown(self):
         super(WebserverTestCase, self).tearDown()
+        self._web_server.stop_accepting()
         self._web_server.stop()
